@@ -23,6 +23,7 @@
 
 #include "diskglobal.h"
 #include <QProcessEnvironment>
+#include <QApplication>
 
 DiskGlobal::DiskGlobal(QObject * parent):QObject (parent)
 {
@@ -31,14 +32,7 @@ DiskGlobal::DiskGlobal(QObject * parent):QObject (parent)
 
 bool DiskGlobal::isWayLand()
 {
-    auto e = QProcessEnvironment::systemEnvironment();
-    QString XDG_SESSION_TYPE = e.value(QStringLiteral("XDG_SESSION_TYPE"));
-    QString WAYLAND_DISPLAY = e.value(QStringLiteral("WAYLAND_DISPLAY"));
-
-    //在wayland平台下设置固定大小，解决属性框最大化问题
-    if (XDG_SESSION_TYPE == QLatin1String("wayland") ||
-            WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) {
-        return true;
-    }
-    return false;
+    //! 该函数只能在QApplication之后调用才能返回有效的值，在此之前会返回空值
+    Q_ASSERT(qApp);
+    return QApplication::platformName() == "wayland";
 }
