@@ -143,7 +143,9 @@ public slots:
     void actionFormatDevice(const QSharedPointer<DFMUrlBaseEvent> &event);
     void actionOpticalBlank(const QSharedPointer<DFMUrlBaseEvent> &event);
     void actionRemoveStashedMount(const QSharedPointer<DFMUrlBaseEvent> &event);
-
+    void doRemoveStashedMount(const QString& path);
+    void actionUnmountAllSmbMount(const QSharedPointer<DFMUrlListBaseEvent> &event);
+    void actionForgetAllSmbPassword(const QSharedPointer<DFMUrlListBaseEvent> &event);
 
     void actionctrlL(quint64 winId);
     void actionctrlF(quint64 winId);
@@ -154,6 +156,7 @@ public slots:
     void actionForward(quint64 winId);
 
     void actionForgetPassword(const QSharedPointer<DFMUrlBaseEvent> &event);
+    void doForgetPassword(const QString& path);
 
     void actionOpenFileByApp();
     void actionSendToRemovableDisk();
@@ -221,7 +224,6 @@ public:
     static QPair<QList<DUrl>, quint64> multiSelectionFilesCache;  //###: for multi selection.
     static std::atomic<quint64> multiSelectionFilesCacheCounter;
     static std::atomic<bool> flagForDDesktopRenameBar;
-
     StartManagerInterface *startManagerInterface() const;
     bool checkLaunchAppInterface();
 };
