@@ -85,8 +85,15 @@ DFMSideBarItem *DFMSideBarDeviceItemHandler::createItem(const DUrl &url)
     }
     QString displayName = infoPointer->fileDisplayName();
     QString iconName = infoPointer->iconName() + "-symbolic";
-
-    DFMSideBarItem * item = new DFMSideBarItem(QIcon::fromTheme(iconName), displayName, url);
+    if(url.scheme() == SMB_SCHEME){
+        if (displayName.isEmpty()) {
+            displayName = url.host();
+        }
+        if (iconName == "-symbolic") {
+            iconName = "folder-remote-symbolic";
+        }
+    }
+    DFMSideBarItem *item = new DFMSideBarItem(QIcon::fromTheme(iconName), displayName, url);
 
     Qt::ItemFlags flags = Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemNeverHasChildren;
 
@@ -150,12 +157,19 @@ QMenu *DFMSideBarDeviceItemHandler::contextMenu(const DFMSideBar *sidebar, const
         disabled.insert(MenuAction::Property);
     }
 
-    if (item->url().path().endsWith(".remote")) {
+    if (item->url().path().endsWith(QString(".%1").arg(SUFFIX_STASHED_REMOTE))) {
         disabled.remove(MenuAction::Mount);
         disabled.remove(MenuAction::Property);
     }
+    QVector<MenuAction> av = infoPointer->menuActionList();
+    bool isSmbIp = FileUtils::isSmbHostOnly(item->url());
+    if(isSmbIp){
+        av.clear();//对于侧边栏smb挂载聚合项的右键菜单只显示 卸载 和 取消记住密码并卸载
+        av.push_back(MenuAction::UnmountAllSmbMount);
+        av.push_back(MenuAction::ForgetAllSmbPassword);
+    }
 
-    DFileMenu *menu = DFileMenuManager::genereteMenuByKeys(infoPointer->menuActionList(), disabled);
+    DFileMenu *menu = DFileMenuManager::genereteMenuByKeys(av, disabled);
     menu->setEventData(DUrl(), {item->url()}, WindowManager::getWindowId(wnd), sidebar);
     menu->setAccessibleInfo(AC_FILE_MENU_SIDEBAR_DEVICE_ITEM);
 
