@@ -156,7 +156,6 @@ void UDiskListener::addDevice(UDiskDeviceInfoPointer device)
     m_map.insert(device->getDiskInfo().id(), device);
     m_list.append(device);
 
-
     DAbstractFileWatcher::ghostSignal(DUrl(DEVICE_ROOT),
                                       &DAbstractFileWatcher::subfileCreated,
                                       DUrl::fromDeviceId(device->getId()));
@@ -334,7 +333,8 @@ bool UDiskListener::isInRemovableDeviceFolder(const QString &path) const
         UDiskDeviceInfoPointer info = m_list.at(i);
         if (mediaTypes.contains(info->getMediaType())) {
             if (!info->getMountPointUrl().isEmpty()) {
-                if (path.startsWith(info->getMountPointUrl().toLocalFile())) {
+                const QString &localPath = info->getMountPointUrl().toLocalFile();
+                if (localPath != "/" && !localPath.isEmpty() && path.startsWith(localPath)) {
                     return true;
                 }
             }
@@ -602,6 +602,36 @@ bool UDiskListener::isFromNativeBlockDev(const QString &mntPath)
     return ret;
 }
 
+int UDiskListener::getCountOfMountedSmb(const QString& ip)
+{
+    int sum = 0;
+    foreach (UDiskDeviceInfoPointer device, m_list) {
+        DUrl url(device->getDiskInfo().mounted_root_uri());
+        if(url.scheme() == SMB_SCHEME && !ip.isEmpty() && url.host() == ip){
+            sum++;
+        }
+    }
+    return sum;
+}
+
+void UDiskListener::setBatchedRemovingSmbMount(bool value)
+{
+    m_isBatchedRemovingSmbMount = value;
+}
+
+bool UDiskListener::isBatchedRemovingSmbMount()
+{
+    return m_isBatchedRemovingSmbMount;
+}
+
+/**
+ * @brief UDiskListener::clearLoginData 清除用于SMB重复鉴权的数据
+ */
+void UDiskListener::clearLoginData()
+{
+    gvfsMountManager->clearLoginData();
+}
+
 void UDiskListener::addMountDiskInfo(const QDiskInfo &diskInfo)
 {
     qDebug() << diskInfo;
