@@ -1270,7 +1270,7 @@ QFrame *PropertyDialog::createBasicInfoWidget(const DAbstractFileInfoPointer &in
         locationPathLabel = new SectionValueLabel();
         QString absoluteFilePath = info->absoluteFilePath();
         //! 在属性窗口中不显示保险箱中的文件真实路径
-        if (info->fileUrl().isVaultFile()) {
+        if (info->fileUrl().isVaultFile() || (info->fileUrl().isSearchFile() && info->fileUrl().fragment().startsWith(DFMVAULT_SCHEME))) {
             absoluteFilePath = VaultController::pathToVirtualPath(absoluteFilePath);
         }
         locationPathLabel->setText(absoluteFilePath);
@@ -1405,9 +1405,10 @@ QList<QPair<QString, QString> > PropertyDialog::createLocalDeviceInfoWidget(cons
     if (!redirectedFileUrl.isEmpty()) {
         if (redirectedFileUrl.burnIsOnDisc()) {
             if (!redirectedFileUrl.burnDestDevice().isEmpty()) {
+                QString burnDevice = redirectedFileUrl.burnDestDevice().replace("/", "_");
                 DUrl stagingUrl = DUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation)
                                                       + "/" + qApp->organizationName() + "/" DISCBURN_STAGING "/"
-                                                      + redirectedFileUrl.burnDestDevice().replace('/', '_'));
+                                                      + burnDevice);
                 QString stagingFilePath = stagingUrl.toLocalFile();
                 if (!stagingFilePath.isEmpty()) {
                     fileCount = FileUtils::filesCount(stagingFilePath);
