@@ -44,14 +44,8 @@
 #define SUFFIX_APP_ENTRY        "appentry"
 
 #define COMPARE_FUN_DEFINE(Value, Name, Type) \
-    bool compareFileListBy##Name(const DAbstractFileInfoPointer &info1, const DAbstractFileInfoPointer &info2, Qt::SortOrder order)\
+    bool compareFileListBy##Name(const DAbstractFileInfoPointer &info1, const DAbstractFileInfoPointer &info2, Qt::SortOrder order, bool isMixedSort)\
     {\
-        bool isDir1 = info1->isDir();\
-        bool isDir2 = info2->isDir();\
-        \
-        bool isFile1 = info1->isFile();\
-        bool isFile2 = info2->isFile();\
-        \
         if (!static_cast<const Type*>(info1.data())) \
             return false; \
         if (!static_cast<const Type*>(info2.data())) \
@@ -59,16 +53,27 @@
         auto value1 = static_cast<const Type*>(info1.data())->Value();\
         auto value2 = static_cast<const Type*>(info2.data())->Value();\
         \
-        if (isDir1) {\
-            if (!isDir2) return true;\
+        if (!isMixedSort) {\
+            bool isDir1 = info1->isDir();\
+            bool isDir2 = info2->isDir();\
+            \
+            bool isFile1 = info1->isFile();\
+            bool isFile2 = info2->isFile();\
+            \
+            if (isDir1) {\
+                if (!isDir2) return true;\
+            } else {\
+                if (isDir2) return false;\
+            }\
+            \
+            if ((isDir1 && isDir2 && (value1 == value2)) || (isFile1 && isFile2 && (value1 == value2))) {\
+                return compareByString(info1->fileDisplayName(), info2->fileDisplayName());\
+            }\
+            \
         } else {\
-            if (isDir2) return false;\
+            if (value1 == value2)\
+                return compareByString(info1->fileDisplayName(), info2->fileDisplayName());\
         }\
-        \
-        if ((isDir1 && isDir2 && (value1 == value2)) || (isFile1 && isFile2 && (value1 == value2))) {\
-            return compareByString(info1->fileDisplayName(), info2->fileDisplayName());\
-        }\
-        \
         bool isStrType = typeid(value1) == typeid(QString);\
         if (isStrType)\
             return compareByString(value1, value2, order);\
@@ -284,7 +289,7 @@ public:
     /// user column default visible for role
     virtual bool columnDefaultVisibleForRole(int role) const;
 
-    typedef std::function<bool(const DAbstractFileInfoPointer &, const DAbstractFileInfoPointer &, Qt::SortOrder)> CompareFunction;
+    typedef std::function<bool(const DAbstractFileInfoPointer &, const DAbstractFileInfoPointer &, Qt::SortOrder, bool)> CompareFunction;
     virtual CompareFunction compareFunByColumn(int columnRole) const;
     /// Whether the file should be inserted into a position according to the current sort type and order
     virtual bool hasOrderly() const;
