@@ -58,6 +58,7 @@
 #include <ddialog.h>
 #include "execinfo.h"
 #include "math.h"
+#include "gvfs/networkmanager.h"
 
 #include <QUrl>
 #include <QDebug>
@@ -271,18 +272,10 @@ bool DFileService::fmEvent(const QSharedPointer<DFMEvent> &event, QVariant *resu
 
             const DAbstractFileInfoPointer &f = createFileInfo(this, durl);
             if (f && f->exists()) {
-                // 如果传入的 event 中 silent 为 true，就不再弹框询问是否删除
-                auto delEvent = dynamic_cast<DFMDeleteEvent *>(event.data());
-                bool deleteFileSilently = delEvent && delEvent->silent();
-                if (deleteFileSilently || DThreadUtil::runInMainThread(dialogManager, &DialogManager::showDeleteFilesClearTrashDialog, DFMUrlListBaseEvent(nullptr, event->fileUrlList())) == DDialog::Accepted) {
-                    // 这里已经确认删除了，同次调用走静默删除，避免二次弹窗
-                    if (delEvent)
-                        delEvent->setProperty(QT_STRINGIFY(DFMDeleteEvent::silent), true);
-                    result = CALL_CONTROLLER(deleteFiles);
-                    if (result.toBool()) {
-                        for (const DUrl &r : event->fileUrlList()) {
-                            emit fileDeleted(r);
-                        }
+                result = CALL_CONTROLLER(deleteFiles);
+                if (result.toBool()) {
+                    for (const DUrl &r : event->fileUrlList()) {
+                        emit fileDeleted(r);
                     }
                 }
 
@@ -612,12 +605,11 @@ bool DFileService::deleteFiles(const QObject *sender, const DUrlList &list, bool
         }
     }
 
-//    if (!confirmationDialog || DThreadUtil::runInMainThread(dialogManager, &DialogManager::showDeleteFilesClearTrashDialog, DFMUrlListBaseEvent(sender, list)) == DDialog::Accepted) {
-//    if (!confirmationDialog ) {
-    return DFMEventDispatcher::instance()->processEventWithEventLoop(dMakeEventPointer<DFMDeleteEvent>(sender, list, slient, force)).toBool();
-//    }
+    if (!confirmationDialog || DThreadUtil::runInMainThread(dialogManager, &DialogManager::showDeleteFilesClearTrashDialog, DFMUrlListBaseEvent(sender, list)) == DDialog::Accepted) {
+        return DFMEventDispatcher::instance()->processEventWithEventLoop(dMakeEventPointer<DFMDeleteEvent>(sender, list, slient, force)).toBool();
+    }
 
-//    return false;
+    return false;
 }
 
 DUrlList DFileService::moveToTrash(const QObject *sender, const DUrlList &list) const
@@ -630,15 +622,18 @@ DUrlList DFileService::moveToTrash(const QObject *sender, const DUrlList &list)
     {
         QList<QUrl> org = DFMGlobal::instance()->clipboardFileUrlList();
         DFMGlobal::ClipboardAction action = DFMGlobal::instance()->clipboardAction();
+        bool isRemoved = false;
         if (!org.isEmpty() && action != DFMGlobal::UnknowAction) {
             for (const DUrl &nd : list) {
                 if (org.isEmpty())
                     break;
-                org.removeAll(nd);
+                int count = org.removeAll(nd);
+                if (count != 0)
+                    isRemoved = true;
             }
             if (org.isEmpty()) //没有文件则清空剪切板
                 DFMGlobal::clearClipboard();
-            else
+            else if (isRemoved)
                 DFMGlobal::setUrlsToClipboard(org, action);
         }
     }
@@ -1012,6 +1007,10 @@ bool DFileService::checkGvfsMountfileBusy(const DUrl &url, const bool showdailog
         }
         rooturl = url;
     } else {
+        if(url.scheme() == SMB_SCHEME && rooturl.isEmpty()){
+            if(networkManager->isFetchingNetworks())//此处若没有此判断，会导致高频访问smb://host卡死
+                return true;
+        }
         static QRegularExpression regExp(GVFS_MATCH_EX,
                                          QRegularExpression::DotMatchesEverythingOption
                                          | QRegularExpression::DontCaptureOption
