@@ -150,11 +150,10 @@ void DFileSystemWatcherPrivate::_q_readFromInotify()
 //    qDebug() << "QInotifyFileSystemWatcherEngine::readFromInotify";
 
     int buffSize = 0;
-    ioctl(inotifyFd, FIONREAD, (char *) &buffSize);
     // fix task#36123 【自测】【桌面专业版】【SP2】【wayland】【文件管理器】 文件管理器概率出现卡死
-    if (buffSize == 0) {
+    if (ioctl(inotifyFd, FIONREAD, (char *) &buffSize) <0 || buffSize == 0)
         return;
-    }
+
     QVarLengthArray<char, 4096> buffer(buffSize);
     buffSize = static_cast<int>(read(inotifyFd, buffer.data(), static_cast<size_t>(buffSize)));
     char *at = buffer.data();
@@ -247,13 +246,13 @@ void DFileSystemWatcherPrivate::_q_readFromInotify()
             if (paths.isEmpty())
                 continue;
         }
-        const QString &name = QString::fromUtf8(event.name);
+        const QString &name = QString::fromUtf8(event.name, static_cast<int>(strlen(event.name)));
 
         for (auto &path : paths) {
 //            qDebug() << "event for path" << path;
 
             /// TODO: Existence of invalid utf8 characters QFile can not read the file information
-            if (event.name != QString::fromLocal8Bit(event.name).toLocal8Bit()) {
+            if (event.name != QString::fromLocal8Bit(event.name, static_cast<int>(strlen(event.name))).toLocal8Bit()) {
                 if (event.mask & (IN_CREATE | IN_MOVED_TO)) {
                     DFMGlobal::fileNameCorrection(path);
                 }
