@@ -47,6 +47,7 @@
 #include "controllers/vaultcontroller.h"
 #include "dfmstandardpaths.h"
 #include "deviceinfo/udisklistener.h"
+#include "shutil/fileutils.h"
 
 #include <sys/stat.h>
 
@@ -241,6 +242,13 @@ void DFileViewHelperPrivate::init()
         DUrlList selectedUrls = q->selectedUrls();
         qInfo() << " ctrl X writeFilesToClipboard and selectedUrls = " << selectedUrls
                 << " currentUrl = " << q->currentUrl();
+
+        // 用户库目录以及主目录禁止剪切
+        for (const DUrl &url : selectedUrls) {
+            if(FileUtils::isContainProhibitPath(url))
+                return;
+        }
+
         fileService->writeFilesToClipboard(q, DFMGlobal::CutAction, selectedUrls);
     });
 
@@ -807,7 +815,7 @@ void DFileViewHelper::preproccessDropEvent(QDropEvent *event) const
 
         if (qApp->keyboardModifiers() == Qt::AltModifier) {
             default_action = Qt::MoveAction;
-        } else if (!DFMGlobal::keyCtrlIsPressed()) {
+        } else if (qApp->queryKeyboardModifiers() != Qt::ControlModifier) {
             // 如果文件和目标路径在同一个分区下，默认为移动文件，否则默认为复制文件
             if (DStorageInfo::inSameDevice(from, to)) {
                 default_action = Qt::MoveAction;
@@ -890,7 +898,7 @@ void DFileViewHelper::preproccessDropEvent(QDropEvent *event, const QList<QUrl>
 
         if (qApp->keyboardModifiers() == Qt::AltModifier) {
             default_action = Qt::MoveAction;
-        } else if (!DFMGlobal::keyCtrlIsPressed()) {
+        } else if (qApp->queryKeyboardModifiers() != Qt::ControlModifier) {
             // 如果文件和目标路径在同一个分区下，默认为移动文件，否则默认为复制文件
             if (DStorageInfo::inSameDevice(from, to)) {
                 default_action = Qt::MoveAction;
