@@ -123,7 +123,8 @@ void DFMCrumbBarPrivate::updateController(const DUrl &url)
         // Not found? Then nothing here...
         if (!crumbController) {
             qDebug() << "Unsupported url / scheme: " << newurl;
-        }
+        } else
+            crumbController->setParent(q_ptr);
     }
 }
 
@@ -281,6 +282,11 @@ void DFMCrumbBarPrivate::initConnections()
         }
     });
 
+    q->connect(addressBar, &DFMAddressBar::pauseButtonClicked, q, [this]() {
+        if (crumbController)
+            crumbController->processAction(DFMCrumbInterface::PauseButtonClicked);
+    });
+
     q->connect(DFMApplication::instance(), &DFMApplication::csdClickableAreaAttributeChanged, q, [this](bool enabled) {
         setClickableAreaEnabled(enabled);
     });
@@ -425,6 +431,7 @@ void DFMCrumbBar::updateCrumbs(const DUrl &url)
         fileUrl = VaultController::localToVault(url.toLocalFile());
     }
 
+    //NOTE [HMOE REN] 已注册的CrumbController(面包屑)创建的面包屑值
     QList<CrumbData> crumbDataList = d->crumbController->seprateUrl(fileUrl);
     for (const CrumbData &c : crumbDataList) {
         if (d->crumbListviewModel) {
@@ -435,7 +442,7 @@ void DFMCrumbBar::updateCrumbs(const DUrl &url)
             } else {
                 listitem = new QStandardItem(c.displayText);
             }
-
+            listitem->setTextAlignment(Qt::AlignCenter);//垂直与水平居中
             listitem->setCheckable(false);
             listitem->setData(c.url, DFMCrumbListviewModel::FileUrlRole);
             d->crumbListviewModel->appendRow(listitem);
@@ -588,8 +595,11 @@ void DFMCrumbBar::onListViewContextMenu(const QPoint &point)
     }
 
     DFileManagerWindow *wnd = qobject_cast<DFileManagerWindow *>(window());
-    if (!wnd)
+    if (!wnd) {
+        menu->deleteLater();
+        menu = nullptr;
         return;
+    }
 
     bool shouldDisable = !WindowManager::tabAddableByWinId(wnd->windowId());
     menu->addAction(copyIcon, QObject::tr("Copy path"), [ = ]() {
