@@ -344,7 +344,7 @@ DFMUrlListBaseEvent::DFMUrlListBaseEvent(DFMEvent::Type type, const QObject *sen
         for (DUrl url : list) {
             //判断是否是来自数据盘路径
             //fix bug63348 在最近使用文件夹下无法删除/data目录下的文件，因为在删除的时候把/data/home处理成/home
-            if (url.path().startsWith("/data/") && !url.isRecentFile()) {
+            if (url.path().startsWith("/data/home/") && !url.isRecentFile()) {
                 //去掉数据盘路径开头
                 url.setPath(url.path().mid(sizeof("/data") - 1));
             }
@@ -950,6 +950,16 @@ const QModelIndex DFMMenuActionEvent::clickedIndex() const
     return property(QT_STRINGIFY(DFMMenuActionEvent::clickedIndex), QModelIndex());
 }
 
+const QList<QColor> DFMMenuActionEvent::tagColors() const
+{
+    return m_tagColorsList;
+}
+
+void DFMMenuActionEvent::setTagColors(const QList<QColor> &list)
+{
+    m_tagColorsList = list;
+}
+
 QSharedPointer<DFMMenuActionEvent> DFMMenuActionEvent::fromJson(const QJsonObject &json)
 {
     const QSharedPointer<DFMMenuActionEvent> &event = DFMUrlListBaseEvent::fromJson(MenuAction, json).staticCast<DFMMenuActionEvent>();
