@@ -41,6 +41,11 @@
 #include "utils.h"
 #include "dfmapplication.h"
 #include "plugins/schemepluginmanager.h"
+#include "utils/grouppolicy.h"
+#include "controllers/dfmrootcontroller.h"
+
+#include <ddiskmanager.h>
+#include <dblockdevice.h>
 
 #include <QUrl>
 #include <QDebug>
@@ -70,6 +75,11 @@ DRootFileManager::DRootFileManager(QObject *parent)
     : QObject(parent)
     , d_ptr(new DRootFileManagerPrivate())
 {
+    if (DTK_POLICY_SUPPORT) {
+        connect(GroupPolicy::instance(), &GroupPolicy::valueChanged, this, &DRootFileManager::policyHideSystemPartition);
+        connect(fileSignalManager, &FileSignalManager::requestHideSystemPartition, this, &DRootFileManager::settingHideSystemPartition);
+    }
+
     connect(fileSignalManager, &FileSignalManager::requestHideSystemPartition, this, &DRootFileManager::hideSystemPartition);
     connect(DFMApplication::instance(), &DFMApplication::reloadComputerModel, this, &DRootFileManager::hideSystemPartition);
 }
@@ -130,9 +140,20 @@ void DRootFileManager::changeRootFile(const DUrl &fileurl, const bool bcreate)
         }
     } else {
         qDebug() << "  remove   " << d_ptr->rootfilelist;
+        bool isRemoded = false;
         if (d_ptr->rootfilelist.contains(fileurl)) {
-            qInfo() << "  remove   " << fileurl;
-            d_ptr->rootfilelist.remove(fileurl);
+            isRemoded = d_ptr->rootfilelist.remove(fileurl)>=1;
+        }
+        if(!isRemoded){//当配置成smb常驻时，d_ptr->rootfilelist中保存的是：dfmroot:///smb://host/share_folder.remote
+            QString path = QUrl::fromPercentEncoding(fileurl.path().toUtf8());
+            if (path.contains(QString(".%1").arg(SUFFIX_GVFSMP)) && path.contains("gvfs/smb-share:server=") && path.contains(",share=")) {
+                QString host = path.section("server=",-1).section(",",0,0);
+                QString shardFolder = path.section("share=",-1).section(QString(".%1").arg(SUFFIX_GVFSMP),0,0);
+                DUrl tem(QString("dfmroot:///smb://%1/%2.remote").arg(host).arg(shardFolder));//tem like: dfmroot:///smb://host/share_folder.remote
+                if (d_ptr->rootfilelist.contains(tem)) {
+                    d_ptr->rootfilelist.remove(tem);
+                }
+            }
         }
     }
 }
@@ -268,7 +289,10 @@ const DAbstractFileInfoPointer DRootFileManager::getFileInfo(const DUrl &fileUrl
 
 bool DRootFileManager::isRootFileContainSmb(const DUrl &smburl)
 {
-    const QString &smburlPath = smburl.path();
+    DUrl temUrl = smburl;
+    if(smburl.scheme() == "smb")
+        temUrl = DUrl(QString("%1%2").arg(DFMROOT_ROOT).arg(smburl.toString()));
+    const QString &smburlPath = temUrl.path();//smburl.path();
     if(!FileUtils::isSmbPath(smburlPath))
         return false;
 
@@ -288,11 +312,10 @@ bool DRootFileManager::isRootFileContainSmb(const DUrl &smburl)
 
 // sometimes we can use this function to relaod computer model.
 // and i think this function called reloadComputerModel could be better.
-
 void DRootFileManager::hideSystemPartition()
 {
     QList<DAbstractFileInfoPointer> fileist = DFileService::instance()->\
-                                              getChildren(this, DUrl(DFMROOT_ROOT), QStringList(), QDir::AllEntries, QDirIterator::NoIteratorFlags, false);
+            getChildren(this, DUrl(DFMROOT_ROOT), QStringList(), QDir::AllEntries, QDirIterator::NoIteratorFlags, false);
     d_ptr->rootfileMtx.lock();
     d_ptr->rootfilelist.clear();
     d_ptr->rootfileMtx.unlock();
@@ -300,3 +323,74 @@ void DRootFileManager::hideSystemPartition()
 
     emit serviceHideSystemPartition();
 }
+
+void DRootFileManager::policyHideSystemPartition(const QString &key)
+{
+    if (DTK_POLICY_SUPPORT) {
+        if (key != DISK_HIDDEN)
+            return;
+        QStringList policyList = GroupPolicy::instance()->getValue(DISK_HIDDEN).toStringList();
+        bool isHidden = DFMApplication::genericAttribute(DFMApplication::GA_HiddenSystemPartition).toBool();
+
+        if (0 == policyList.count() && !isHidden)
+            return;
+
+        QStringList systemDisks = DFMRootController::systemDiskList();
+        bool allHidden = true;
+        for (auto dk : systemDisks){
+            if (!policyList.contains(dk)) {
+                allHidden = false;
+                break;
+            }
+        }
+
+        if (allHidden && isHidden)
+            return;
+
+        if (allHidden && !isHidden)
+            DFMApplication::instance()->setGenericAttribute(DFMApplication::GA_HiddenSystemPartition, true);
+
+        if (!allHidden && isHidden)
+            DFMApplication::instance()->setGenericAttribute(DFMApplication::GA_HiddenSystemPartition, false);
+
+
+        QList<DAbstractFileInfoPointer> fileist = DFileService::instance()->\
+                getChildren(this, DUrl(DFMROOT_ROOT), QStringList(), QDir::AllEntries, QDirIterator::NoIteratorFlags, false);
+        d_ptr->rootfileMtx.lock();
+        d_ptr->rootfilelist.clear();
+        d_ptr->rootfileMtx.unlock();
+        changRootFile(fileist);
+
+        emit serviceHideSystemPartition();
+    }
+}
+
+void DRootFileManager::settingHideSystemPartition(bool isHide)
+{
+    Q_UNUSED(isHide)
+
+    if (DTK_POLICY_SUPPORT) {
+        bool isSetPolicy = GroupPolicy::instance()->containKey(DISK_HIDDEN);
+        if (isSetPolicy) {
+            bool isHidden = DFMApplication::genericAttribute(DFMApplication::GA_HiddenSystemPartition).toBool();
+            auto policyList = GroupPolicy::instance()->getValue(DISK_HIDDEN).toList();
+
+            if (isHidden) {
+                QStringList systemDisks = DFMRootController::systemDiskList();
+                bool allHidden = true;
+                for (auto dk : systemDisks){
+                    if (!policyList.contains(dk)) {
+                        allHidden = false;
+                        policyList << dk;
+                    }
+                }
+
+                if (!allHidden)
+                    GroupPolicy::instance()->setValue(DISK_HIDDEN, policyList);
+            } else {
+                if (!policyList.isEmpty())
+                    GroupPolicy::instance()->setValue(DISK_HIDDEN, QVariantList());
+            }
+        }
+    }
+}
