@@ -71,6 +71,9 @@ signals:
 
 public Q_SLOTS:
     void hideSystemPartition();
+    void policyHideSystemPartition(const QString &key);
+    void settingHideSystemPartition(bool isHide);
+
 
 private:
     explicit DRootFileManager(QObject *parent = nullptr);
