@@ -31,6 +31,7 @@
 #include "fileoperations/filejob.h"
 #include "dfmapplication.h"
 
+#include <QUrl>
 #include <QCryptographicHash>
 #include <QDir>
 #include <QDateTime>
@@ -61,7 +62,6 @@ DFM_BEGIN_NAMESPACE
 
 #define FORMAT ".png"
 //#define CREATE_VEDIO_THUMB "CreateVedioThumbnail"
-
 inline QByteArray dataToMd5Hex(const QByteArray &data)
 {
     return QCryptographicHash::hash(data, QCryptographicHash::Md5).toHex();
@@ -132,6 +132,9 @@ void DThumbnailProviderPrivate::init()
     sizeLimitHash.insert(mimeDatabase.mimeTypeForName("image/jpeg"), 1024 * 1024 * 30);
     sizeLimitHash.insert(mimeDatabase.mimeTypeForName("image/png"), 1024 * 1024 * 30);
     sizeLimitHash.insert(mimeDatabase.mimeTypeForName("image/pipeg"), 1024 * 1024 * 30);
+
+    // High file limit size only for FLAC files.
+    sizeLimitHash.insert(mimeDatabase.mimeTypeForName("audio/flac"), INT64_MAX);
 }
 
 QString DThumbnailProviderPrivate::sizeToFilePath(DThumbnailProvider::Size size) const
@@ -190,6 +193,10 @@ bool DThumbnailProvider::hasThumbnail(const QMimeType &mimeType) const
     if (mime.startsWith("image") && !DFMApplication::instance()->genericAttribute(DFMApplication::GA_PreviewImage).toBool())
         return false;
 
+    if ((mime.startsWith("audio") || mimeTypeDisplayManager->supportAudioMimeTypes().contains(mime))
+            && !DFMApplication::instance()->genericAttribute(DFMApplication::GA_PreviewAudio).toBool())
+        return false;
+
     if ((mime.startsWith("video") || mimeTypeDisplayManager->supportVideoMimeTypes().contains(mime))
             && !DFMApplication::instance()->genericAttribute(DFMApplication::GA_PreviewVideo).toBool())
         return false;
@@ -207,9 +214,8 @@ bool DThumbnailProvider::hasThumbnail(const QMimeType &mimeType) const
     if (DThumbnailProviderPrivate::hasThumbnailMimeHash.contains(mime))
         return true;
 
-    if (Q_LIKELY(mime.startsWith("image") || mime.startsWith("video/"))) {
+    if (Q_LIKELY(mime.startsWith("image") || mime.startsWith("audio/") || mime.startsWith("video/"))) {
         DThumbnailProviderPrivate::hasThumbnailMimeHash.insert(mime);
-
         return true;
     }
 
@@ -518,10 +524,52 @@ QString DThumbnailProvider::createThumbnail(const QFileInfo &info, DThumbnailPro
         }
 
         *image = img.scaled(QSize(size, size), Qt::KeepAspectRatio, Qt::SmoothTransformation);
-    } else {
-        thumbnail = DTK_GUI_NAMESPACE::DThumbnailProvider::instance()->createThumbnail(info, (DTK_GUI_NAMESPACE::DThumbnailProvider::Size)size);
-        d->errorString = DTK_GUI_NAMESPACE::DThumbnailProvider::instance()->errorString();
+    } else if (mime.name().startsWith("audio/")) {
+        QProcess ffmpeg;
+        ffmpeg.start("ffmpeg", QStringList() << "-nostats"
+                     << "-loglevel" << "0"
+                     << "-i" << QDir::toNativeSeparators(absoluteFilePath)
+                     << "-an"
+                     << "-vf" << "scale='min(" + QString::number(size) + ",iw)':-1"
+                     << "-f" << "image2pipe"
+                     << "-fs" << "9000"
+                     << "-",
+                     QIODevice::ReadOnly);
 
+        if (!ffmpeg.waitForFinished()) {
+            d->errorString = ffmpeg.errorString();
+            goto _return;
+        }
+
+        const QByteArray output = ffmpeg.readAllStandardOutput();
+
+        if (image->loadFromData(output)) {
+            d->errorString.clear();
+        } else {
+            d->errorString = QString("load image failed from the ffmpeg application");
+        }
+    } else {
+        //显式调用库函数getMovieCover获取视频缩略图，以兼容文管旧版本
+        bool thumnailCreatedByMovieLib = false;
+        //获取缩略图生成库函数getMovieCover的指针
+        if(m_libMovieViewer && m_libMovieViewer->isLoaded()){
+            typedef void(*getMovieCover)(const QUrl &url, const QString &savePath, QImage *imageRet);
+            getMovieCover func= reinterpret_cast<void(*)(const QUrl &, const QString &, QImage *)>(m_libMovieViewer->resolve("getMovieCover"));
+            if(func){//存在导出函数getMovieCover
+                auto url = QUrl::fromLocalFile(absoluteFilePath);
+                QImage img;
+                func(url,absolutePath,&img);//调用getMovieCover生成缩略图
+                if(!img.isNull()){
+                    *image = img;
+                    thumnailCreatedByMovieLib = true;
+                }
+            }
+        }
+        if(thumnailCreatedByMovieLib){//调用库函数getMovieCover提取缩略图成功
+            d->errorString.clear();
+        }else{//若调用库函数getMovieCover提取缩略图失败，下面走旧逻辑
+            thumbnail = DTK_GUI_NAMESPACE::DThumbnailProvider::instance()->createThumbnail(info, (DTK_GUI_NAMESPACE::DThumbnailProvider::Size)size);
+            d->errorString = DTK_GUI_NAMESPACE::DThumbnailProvider::instance()->errorString();
         if (d->errorString.isEmpty()) {
             emit createThumbnailFinished(absoluteFilePath, thumbnail);
             emit thumbnailChanged(absoluteFilePath, thumbnail);
@@ -617,7 +665,8 @@ QString DThumbnailProvider::createThumbnail(const QFileInfo &info, DThumbnailPro
                 }
             }
         }
-    }
+     }
+   }
 
 _return:
     // successful
@@ -734,6 +783,8 @@ DThumbnailProvider::DThumbnailProvider(QObject *parent)
     , d_ptr(new DThumbnailProviderPrivate(this))
 {
     d_func()->init();
+    m_libMovieViewer = new QLibrary("libimageviewer.so");
+    m_libMovieViewer->load();
 }
 
 DThumbnailProvider::~DThumbnailProvider()
@@ -743,6 +794,12 @@ DThumbnailProvider::~DThumbnailProvider()
     d->running = false;
     d->waitCondition.wakeAll();
     wait();
+
+    if(m_libMovieViewer && m_libMovieViewer->isLoaded()){
+        m_libMovieViewer->unload();
+        delete m_libMovieViewer;
+        m_libMovieViewer = nullptr;
+    }
 }
 
 void DThumbnailProvider::run()
