@@ -230,10 +230,41 @@ int FileUtils::filesCount(const QString &dir)
     return entryList.size();
 }
 
-QStringList FileUtils::filesList(const QString &dir)
+QFileInfoList FileUtils::fileInfoList(const QString &path)
+{
+    QDir dir(path);
+    if (!dir.exists() || dir.isEmpty())
+        return {};
+
+    return dir.entryInfoList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::NoSymLinks);
+}
+
+/*!
+ * \brief 递归获取目录下所有文件列表，主线程中谨慎使用（文件过多卡死主线程）
+ * \param path
+ * \return
+ */
+QFileInfoList FileUtils::fileInfoListRecursive(const QString &path)
+{
+    QDir dir(path);
+    if (!dir.exists() || dir.isEmpty())
+        return {};
+
+    QFileInfoList fileList {dir.entryInfoList(QDir::Files | QDir::NoSymLinks)};
+    const QFileInfoList &folderList = dir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot);
+
+    for(const QFileInfo &info : folderList) {
+         const QFileInfoList &childFileList = fileInfoListRecursive(info.absoluteFilePath());
+         fileList.append(childFileList);
+    }
+
+    return fileList;
+}
+
+QStringList FileUtils::filesList(const QString &path)
 {
     QStringList appNames;
-    QDirIterator it(dir,
+    QDirIterator it(path,
                     QDir::Files | QDir::NoDotAndDotDot,
                     QDirIterator::Subdirectories);
     while (it.hasNext()) {
@@ -354,8 +385,7 @@ qint64 FileUtils::totalSize(const DUrlList &files, qint32 &dirSize, qint32 &file
             if (flag != FTS_DP)
                 total += ent->fts_statp->st_size <= 0 ? getMemoryPageSize() : ent->fts_statp->st_size;
             if (dirSize == 0 && flag == FTS_D)
-                dirSize = ent->fts_statp->st_size <= 0 ? getMemoryPageSize() :
-                                                                  static_cast<qint32>(ent->fts_statp->st_size);
+                dirSize = ent->fts_statp->st_size <= 0 ? getMemoryPageSize() : static_cast<qint32>(ent->fts_statp->st_size);
             if (flag == FTS_F)
                 fileCount++;
         }
@@ -516,6 +546,34 @@ QIcon FileUtils::searchAppIcon(const DesktopFile &app,
     // Default icon
     return defaultIcon;
 }
+
+QString FileUtils::formatOpticalMediaType(const QString &media)
+{
+    static std::initializer_list<std::pair<QString, QString>> opticalmediakeys {
+        {"optical",                "Optical"},
+        {"optical_cd",             "CD-ROM"},
+        {"optical_cd_r",           "CD-R"},
+        {"optical_cd_rw",          "CD-RW"},
+        {"optical_dvd",            "DVD-ROM"},
+        {"optical_dvd_r",          "DVD-R"},
+        {"optical_dvd_rw",         "DVD-RW"},
+        {"optical_dvd_ram",        "DVD-RAM"},
+        {"optical_dvd_plus_r",     "DVD+R"},
+        {"optical_dvd_plus_rw",    "DVD+RW"},
+        {"optical_dvd_plus_r_dl",  "DVD+R/DL"},
+        {"optical_dvd_plus_rw_dl", "DVD+RW/DL"},
+        {"optical_bd",             "BD-ROM"},
+        {"optical_bd_r",           "BD-R"},
+        {"optical_bd_re",          "BD-RE"},
+        {"optical_hddvd",          "HD DVD-ROM"},
+        {"optical_hddvd_r",        "HD DVD-R"},
+        {"optical_hddvd_rw",       "HD DVD-RW"},
+        {"optical_mo",             "MO"}
+    };
+    static QMap<QString, QString> opticalmediamap(opticalmediakeys);
+
+    return opticalmediamap.value(media);
+}
 //---------------------------------------------------------------------------
 
 QString sizeString(const QString &str)
@@ -639,7 +697,6 @@ QString FileUtils::diskUsageString(quint64 &usedSize, quint64 &totalSize, QStrin
     }
 }
 
-
 /*!
  * \brief 解析配置文件，获取光盘大小数据
  * 光盘打开后可以显示大小，并挂载然而关闭文管后再重新启动会导致之前的状态机失效（未持久化存储）
@@ -649,8 +706,8 @@ QString FileUtils::diskUsageString(quint64 &usedSize, quint64 &totalSize, QStrin
  */
 QString FileUtils::defaultOpticalSize(const QString &tagName, quint64 &usedSize, quint64 &totalSize)
 {
-    QString size{"0M"};
-    int burnStatus{DFMOpticalMediaWidget::BCSA_BurnCapacityStatusEjct};
+    QString size {"0M"};
+    int burnStatus { DFMOpticalMediaWidget::BCSA_BurnCapacityStatusEjct };
     quint64 curTotalSize{0}; // 光盘总大小
     quint64 curUsedSize{0};  // 光盘已使用的大小
 
@@ -669,7 +726,6 @@ QString FileUtils::defaultOpticalSize(const QString &tagName, quint64 &usedSize,
             totalSize = curTotalSize;
             size = QString("%1/%2").arg(FileUtils::formatSize(static_cast<qint64>(usedSize), true, 1, usedSize < mb ? 2 : -1, unitDisplayText),
                                         FileUtils::formatSize(static_cast<qint64>(totalSize), true, 1, totalSize < mb ? 2 : -1, unitDisplayText));
-
         }
     }
 
@@ -1264,7 +1320,7 @@ QByteArray FileUtils::md5(QFile *file, const QString &filePath)
         file->close();
     }
 
-    return QCryptographicHash::hash(md5, QCryptographicHash::Md5).toHex();;
+    return QCryptographicHash::hash(md5, QCryptographicHash::Md5).toHex();
 }
 
 bool FileUtils::isFileExecutable(const QString &path)
@@ -1338,7 +1394,6 @@ bool FileUtils::isFileRunnable(const QString &path)
     return false;
 }
 
-
 bool FileUtils::isFileWindowsUrlShortcut(const QString &path)
 {
     QString mimetype = getFileMimetype(path);
@@ -1357,7 +1412,6 @@ QString FileUtils::getInternetShortcutUrl(const QString &path)
     return url;
 }
 
-
 QString FileUtils::getFileMimetype(const QString &path)
 {
     GFile *file;
@@ -1532,7 +1586,6 @@ QByteArray FileUtils::imageFormatName(QImage::Format f)
     return "jpeg";
 }
 
-
 QString FileUtils::getFileContent(const QString &file)
 {
     QFile f(file);
@@ -1892,8 +1945,8 @@ bool FileUtils::isNetworkUrlMounted(const DUrl &url)
 {
     for (auto gvfsmp : DGioVolumeManager::getMounts()) {
         auto rootFile = gvfsmp->getRootFile();
-        if (!rootFile || (!rootFile->uri().contains("smb")
-                && !rootFile->uri().contains("ftp")))
+        if (!rootFile || (!rootFile->uri().contains(SMB_SCHEME)
+                && !rootFile->uri().contains(FTP_SCHEME)))
             continue;
 
         DUrl mountUrl;
@@ -1927,7 +1980,7 @@ bool FileUtils::isSmbUnmountedFile(const DUrl &url)
 
 bool FileUtils::isSmbPath(const QString &localPath)
 {
-    // like file:///run/user/1000/gvfs/smb-share:domain=ttt,server=xx.xx.xx.xx,share=io,user=uos/path
+    // like file:///run/user/<user_id>/gvfs/smb-share:domain=ttt,server=<host>,share=io,user=uos/path
     QRegExp reg("/run/user/.+gvfs/smb-share:.*server.+share.+");
     int idx = reg.indexIn(localPath);
 
@@ -1945,6 +1998,84 @@ bool FileUtils::isSmbPath(const QString &localPath)
     return -1 != idx;
 }
 
+/**
+ * @brief FileUtils::isSmbShareFolder To judge the give url whether is a smb share folder url,
+ * Its format is like smb://host/share_folder or dfmroot://smb://host/share_folder
+ * @param url
+ * @return Return true if the give url is a smb share folder url
+ */
+bool FileUtils::isSmbShareFolder(const DUrl &url)
+{
+    DUrl temUrl = url;
+    if(url.scheme() == DFMROOT_SCHEME){
+        QString urlString = url.toString();
+        urlString = urlString.remove(DFMROOT_SCHEME);
+        temUrl = DUrl(urlString);
+    }
+    QString path = temUrl.path();
+    if(path.endsWith('/') || path.endsWith('\\')){
+        path.chop(1);
+    }
+    bool result = temUrl.scheme() == SMB_SCHEME && !path.isEmpty() && path.startsWith('/') && path.count("/") == 1;
+    return result;
+}
+
+/**
+ * @brief FileUtils::isSmbRelatedUrl 判断url是否是smb相关的url并输出host
+ * @param url
+ * @param host
+ * @return
+ */
+bool FileUtils::isSmbRelatedUrl(const DUrl &url, QString &host)
+{
+    /*
+      What is smb related url?
+      1、smb folder is mounted, such as:
+      dfmroot:////run/user/<user id>/gvfs/smb-share:server=<host>,share=<share_folder>.gvfsmp
+      2、smb folder is not mounted, such as：
+      dfmroot:///smb://<host>/<share_folder>.remote
+      3、smb ip,such as：
+      smb://<host>
+    */
+    QString decodeUrl = DUrl::fromPercentEncoding(url.path().toUtf8());
+    if(decodeUrl.contains("ftp:host"))
+        return false;
+    if (isSmbPath(url.path()) || url.toString().startsWith("smb://") ) {//ends with .gvfsmp
+        if ( url.path().endsWith( QString( ".%1" ).arg(SUFFIX_GVFSMP)) ){
+            QString path = QUrl::fromPercentEncoding(url.path().toUtf8());
+            host = path.section( "server=" , -1 ).section( "," , 0, 0 );
+        } else if (url.path().endsWith( QString( ".%1" ).arg(SUFFIX_STASHED_REMOTE)) ){//ends with .remote
+            QString smbPath = QUrl::fromPercentEncoding(url.path().toUtf8());
+            if (smbPath.startsWith( "/" ))
+                smbPath = smbPath.mid(1);
+            host = DUrl(smbPath).host();
+        } else {
+            host = url.host();
+        }
+    }
+
+    if (!host.isEmpty()) {
+        return true;
+    }
+    return false;
+}
+
+/**
+ * @brief FileUtils::isSmbHostOnly 判断url格式是否为smb://host或者smb://domain格式
+ * @param url
+ * @return
+ */
+bool FileUtils::isSmbHostOnly(const DUrl &url)
+{
+    if(url.scheme() != SMB_SCHEME)
+        return false;
+    QString urlString = url.toString();
+    if(urlString.endsWith("/") || urlString.endsWith("\\"))
+        urlString.chop(1);
+    bool re = url.scheme()+ "://" + url.host() == url.toString();
+    return re;
+}
+
 DUrl FileUtils::durlFromLocalPath(const QString &localPath)
 {
     // file:///run/user/1000/gvfs/smb-share:domain=ttt,server=xx.xx.xx.xx,share=io,user=uos/path
@@ -2209,5 +2340,4 @@ bool FileUtils::isDesktopFile(const QFileInfo &fileInfo, QMimeType &mimetyp)
     mimetyp = mt;
     return mt.name() == "application/x-desktop" &&
            mt.suffixes().contains("desktop", Qt::CaseInsensitive);
-
 }
