@@ -34,6 +34,9 @@
 #include "dfmsidebaritemdelegate.h"
 #include "dfmsidebaritem.h"
 #include "dfmopticalmediawidget.h"
+#include "gvfs/secretmanager.h"
+#include "dfmeventdispatcher.h"
+#include "gvfs/networkmanager.h"
 
 #include "interfaces/dfmsidebariteminterface.h"
 #include "views/dfmsidebarview.h"
@@ -55,6 +58,9 @@
 #include "dtoolbar.h"
 #include "utils.h"
 #include "controllers/bookmarkmanager.h"
+#include "grouppolicy.h"
+#include "gvfs/networkmanager.h"
+
 
 #include <DApplicationHelper>
 #include <QScrollBar>
@@ -72,6 +78,7 @@
 #include "plugins/schemepluginmanager.h"
 
 #define SIDEBAR_ITEMORDER_KEY "SideBar/ItemOrder"
+#define RECENT_HIDDEN "dfm.recent.hidden"
 
 DFM_BEGIN_NAMESPACE
 
@@ -376,6 +383,21 @@ void DFMSideBar::rootFileResult()
 {
     QList<DAbstractFileInfoPointer> filist  = rootFileManager->getRootFile();
     qDebug() << "DFileService::instance()->getRootFile() filist:" << filist.size();
+    QStringList mountedSmbs;//已经挂载了的smb url
+    foreach (DAbstractFileInfoPointer r, filist) {
+        QString smbIp;
+        FileUtils::isSmbRelatedUrl(r->fileUrl(),smbIp);
+        if (!smbIp.isEmpty()){
+            if (r->fileUrl().toString().endsWith( QString(".%1").arg(SUFFIX_GVFSMP)) && FileUtils::isNetworkUrlMounted( r->fileUrl() ))
+            {
+                filist.removeOne(r);
+            }
+            if (r->fileUrl().toString().endsWith( QString(".%1").arg(SUFFIX_STASHED_REMOTE))){
+                filist.removeOne(r);
+            }
+        }
+    }
+
     if (filist.isEmpty())
         return;
 
@@ -393,27 +415,61 @@ void DFMSideBar::rootFileResult()
             if (Singleton<PathManager>::instance()->isVisiblePartitionPath(fi)) {
                 // 这里需要根据url进行排序
                 const auto &url = fi->fileUrl();
+
                 auto r = std::upper_bound(devitems.begin(), devitems.end(), url,
                 [](const DUrl & a, const DUrl & b) {
                     DAbstractFileInfoPointer fia = fileService->createFileInfo(nullptr, a);
                     DAbstractFileInfoPointer fib = fileService->createFileInfo(nullptr, b);
                     return DFMRootFileInfo::typeCompare(fia, fib);
                 });
+
                 if (r == devitems.end()) {
                     this->addItem(DFMSideBarDeviceItemHandler::createItem(url), this->groupName(Device));
-                    devitems.append(url);
-                } else if (r > devitems.begin() && r < devitems.end()) {
+                        devitems.append(url);
+                } else {
                     this->insertItem(this->findLastItem(this->groupName(Device)) - (devitems.end() - r) + 1, DFMSideBarDeviceItemHandler::createItem(url), this->groupName(Device));
-                    devitems.insert(r, url);
+                        devitems.insert(r, url);
                 }
             }
         }
     }
+    //无论是否设置smb挂载项常驻，此处只依据RemoteMountsStashManager::stashedSmbDevices()中的内容进行界面显示
+    QStringList smbSideBarItems = RemoteMountsStashManager::stashedSmbDevices();
+        foreach (const QString& smbDevice, smbSideBarItems) {
+            if (isSmbItemExisted(DUrl(smbDevice)))
+                removeItem(DUrl(smbDevice), this->groupName(Device));
+            DFMSideBarItem *item = DFMSideBarDeviceItemHandler::createItem(smbDevice);
+            if (item){
+                this->addItem(item, this->groupName(Device));
+            }
+        }
+}
+
+/**
+ * @brief DFMSideBar::jumpToItem
+ */
+void DFMSideBar::jumpToItem(const DUrl& url, GroupName group)
+{
+    int index = findItem(url, groupName(group));
+    DFMSideBarItem *item = m_sidebarModel->itemFromIndex(index);
+    if (item) {
+        QString identifierStr = item->registeredHandler(SIDEBAR_ID_INTERNAL_FALLBACK);
+        QScopedPointer<DFMSideBarItemInterface> interface(DFMSideBarManager::instance()->createByIdentifier(identifierStr));
+        if (interface) {
+                interface->cdAction(this, item);
+        }
+    }
+}
+
+bool DFMSideBar::isSmbItemExisted(const DUrl &smbDevice)
+{
+    int index = findItem(smbDevice, this->groupName(Device));
+    return index >=0;
 }
 
 void DFMSideBar::onItemActivated(const QModelIndex &index)
 {
-    if(!DRootFileManager::instance()->isRootFileInited())
+    if (!DRootFileManager::instance()->isRootFileInited())
         return;
     DFMSideBarItem *item = m_sidebarModel->itemFromIndex(index);
     QString identifierStr = item->registeredHandler(SIDEBAR_ID_INTERNAL_FALLBACK);
@@ -437,8 +493,6 @@ void DFMSideBar::onItemActivated(const QModelIndex &index)
                 return;
             }
         }
-
-
         //判断网络文件是否可以到达
         if (DFileService::instance()->checkGvfsMountfileBusy(item->url())) {
             return;
@@ -473,6 +527,7 @@ void DFMSideBar::onContextMenuRequested(const QPoint &pos)
     QMenu *menu = nullptr;
     if (interface) {
         menu = interface->contextMenu(this, item);
+
         if (menu) {
             // 如果光驱正在执行刻录/擦除操作，禁用光驱的右键菜单
             QString strVolTag = item->url().path().remove("/").remove(".localdisk"); // /sr0.localdisk 去头去尾
@@ -507,7 +562,7 @@ void DFMSideBar::onRename(const QModelIndex &index, QString newName) const
     if (interface && !newName.isEmpty() && item->text() != newName) {
         interface->rename(item, newName);
     }
-    if(m_sidebarView)
+    if (m_sidebarView)
         m_sidebarView->update();
 }
 
@@ -596,16 +651,26 @@ void DFMSideBar::initConnection()
     connect(m_sidebarModel, &QStandardItemModel::rowsInserted, this, &DFMSideBar::updateSeparatorVisibleState);
     connect(m_sidebarModel, &QStandardItemModel::rowsRemoved, this, &DFMSideBar::updateSeparatorVisibleState);
     connect(m_sidebarModel, &QStandardItemModel::rowsMoved, this, &DFMSideBar::updateSeparatorVisibleState);
+
     // drag to move item will emit rowsInserted and rowsMoved..
     connect(m_sidebarModel, &QStandardItemModel::rowsRemoved, this,
-    [this](const QModelIndex & parent, int first, int last) {
+            [this](const QModelIndex & parent, int first, int last) {
         Q_UNUSED(parent);
         Q_UNUSED(last);
+
         DFMSideBarItem *item = m_sidebarModel->itemFromIndex(first);
-        if (!item) {
+        if (!item)
             item = m_sidebarModel->itemFromIndex(first - 1);
+
+        // only bookmark and tag item are DragEnabled
+        if (item && item->flags().testFlag(Qt::ItemIsEnabled) && item->flags().testFlag(Qt::ItemIsDragEnabled)) {
+            saveItemOrder(item->groupName());
+            return;
         }
 
+        if (item->text().isEmpty())
+            item = m_sidebarModel->itemFromIndex(item->index().row() - 1);
+
         // only bookmark and tag item are DragEnabled
         if (item && item->flags().testFlag(Qt::ItemIsEnabled) && item->flags().testFlag(Qt::ItemIsDragEnabled)) {
             saveItemOrder(item->groupName());
@@ -622,6 +687,19 @@ void DFMSideBar::initConnection()
         }
     });
 
+    DFileManagerWindow *window = qobject_cast<DFileManagerWindow *>(this->window());
+    if (window) {
+        connect(networkManager,&NetworkManager::addSmbMountIntegration,this,[&](const DUrl& url){
+            if (url.scheme() != SMB_SCHEME)
+                return;
+            QString smbIp = url.host();
+            bool re = this->isSmbItemExisted(DUrl(("smb://" + smbIp)));
+            if (!re){
+                this->addItem(DFMSideBarDeviceItemHandler::createItem(smbIp.isEmpty() ? url : ("smb://" + smbIp)), this->groupName(Device));
+            }
+        });
+    }
+
     initBookmarkConnection();
 #ifdef ENABLE_ASYNCINIT
     m_initDevThread.first = false;
@@ -675,19 +753,68 @@ void DFMSideBar::initUserShareItem()
 
 void DFMSideBar::initRecentItem()
 {
-    auto recentLambda = [ = ](bool enable) {
-        int index = findItem(DUrl(RECENT_ROOT), groupName(Common));
-        if (index) {
-            m_sidebarView->setRowHidden(index, !enable);
-            if (!enable) {
-                // jump out of recent:///
-                DAbstractFileWatcher::ghostSignal(DUrl(RECENT_ROOT), &DAbstractFileWatcher::fileDeleted, DUrl(RECENT_ROOT));
+    if (DTK_POLICY_SUPPORT) {
+        auto recentLambda = [ = ](bool enable) {
+            int index = findItem(DUrl(RECENT_ROOT), groupName(Common));
+            if (index) {
+                m_sidebarView->setRowHidden(index, !enable);
+                if (!enable) {
+                    // jump out of recent:///
+                    DAbstractFileWatcher::ghostSignal(DUrl(RECENT_ROOT), &DAbstractFileWatcher::fileDeleted, DUrl(RECENT_ROOT));
+                }
+            }
+        };
+
+        auto oldWayRecentLambda = [=](bool var) {
+            recentLambda(var);
+            // sync policy recent
+            auto policyV = GroupPolicy::instance()->getValue(RECENT_HIDDEN);
+            if (policyV.isValid() && policyV.toBool() == var)
+                GroupPolicy::instance()->setValue(RECENT_HIDDEN, !var);
+        };
+
+        auto policyWayRecentLambda = [=](QVariant var){
+            auto tempValue = GroupPolicy::instance()->getValue(RECENT_HIDDEN);
+            auto oldV = DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowRecentFileEntry);
+            if (var.isValid() && (var.toString() == RECENT_HIDDEN) && (tempValue.toBool() == oldV.toBool())) {
+                recentLambda(!tempValue.toBool());
+
+                // sync old recent
+                DFMApplication::instance()->setGenericAttribute(DFMApplication::GA_ShowRecentFileEntry, !tempValue.toBool());
+            }
+        };
+
+        if (!GroupPolicy::instance()->containKey(RECENT_HIDDEN)) {
+            recentLambda(DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowRecentFileEntry).toBool());
+        } else {
+            auto tempValue = GroupPolicy::instance()->getValue(RECENT_HIDDEN);
+            if (tempValue.isValid()) {
+                recentLambda(!tempValue.toBool());
+                // sync old recent
+                auto oldV = DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowRecentFileEntry);
+                if (tempValue.isValid() && tempValue.toBool() == oldV.toBool())
+                    DFMApplication::instance()->setGenericAttribute(DFMApplication::GA_ShowRecentFileEntry, !tempValue.toBool());
+            } else {
+                recentLambda(DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowRecentFileEntry).toBool());
             }
         }
-    };
+        connect(DFMApplication::instance(), &DFMApplication::recentDisplayChanged, this, oldWayRecentLambda);
+        connect(GroupPolicy::instance(), &GroupPolicy::valueChanged, this, policyWayRecentLambda);
+    } else {
+        auto recentLambda = [ = ](bool enable) {
+            int index = findItem(DUrl(RECENT_ROOT), groupName(Common));
+            if (index) {
+                m_sidebarView->setRowHidden(index, !enable);
+                if (!enable) {
+                    // jump out of recent:///
+                    DAbstractFileWatcher::ghostSignal(DUrl(RECENT_ROOT), &DAbstractFileWatcher::fileDeleted, DUrl(RECENT_ROOT));
+                }
+            }
+        };
 
-    recentLambda(DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowRecentFileEntry).toBool());
-    connect(DFMApplication::instance(), &DFMApplication::recentDisplayChanged, this, recentLambda);
+        recentLambda(DFMApplication::instance()->genericAttribute(DFMApplication::GA_ShowRecentFileEntry).toBool());
+        connect(DFMApplication::instance(), &DFMApplication::recentDisplayChanged, this, recentLambda);
+    }
 }
 
 void DFMSideBar::initBookmarkConnection()
@@ -734,6 +861,11 @@ void DFMSideBar::initBookmarkConnection()
 
 void DFMSideBar::initDeviceConnection()
 {
+    // 已经初始化了就直接拿结果
+    if (DRootFileManager::instance()->isRootFileInited()) {
+        rootFileResult();
+    }
+
     // 获取遍历结果进行显示
     connect(DRootFileManager::instance(),&DRootFileManager::queryRootFileFinsh,this,[this](){
         rootFileResult();
@@ -753,15 +885,17 @@ void DFMSideBar::initDeviceConnection()
         rootFileResult();
     },Qt::QueuedConnection);
 
-    // 已经初始化了就直接拿结果
-   if (DRootFileManager::instance()->isRootFileInited()) {
-        rootFileResult();
-    }
     // 开启遍历线程,刷新一次root，修复分区问题
     DRootFileManager::instance()->startQuryRootFile();
 
     DAbstractFileWatcher *devicesWatcher = rootFileManager->rootFileWather();
     connect(devicesWatcher, &DAbstractFileWatcher::subfileCreated, this, [this](const DUrl &url) {
+        QString smbIp;
+        bool needAddSmbItem = FileUtils::isSmbRelatedUrl(url, smbIp);
+        if (needAddSmbItem && isSmbItemExisted(DUrl("smb://"+smbIp))){//已经添加了
+            return;
+        }
+
         auto fi = fileService->createFileInfo(nullptr, url);
         if (!fi->exists()) {
             return;
@@ -780,35 +914,71 @@ void DFMSideBar::initDeviceConnection()
             });
             if (r == devitems.end()) {
                 //DFileService::instance()->changeRootFile(url); //性能优化，注释
-                this->addItem(DFMSideBarDeviceItemHandler::createItem(url), this->groupName(Device));
-                devitems.append(url);
+                this->addItem(DFMSideBarDeviceItemHandler::createItem(smbIp.isEmpty() ? url : ("smb://" + smbIp)), this->groupName(Device));
+                if (smbIp.isEmpty())
+                    devitems.append(url);
             } else {
                 //DFileService::instance()->changeRootFile(url); //性能优化，注释
                 this->insertItem(this->findLastItem(this->groupName(Device)) - (devitems.end() - r) + 1, DFMSideBarDeviceItemHandler::createItem(url), this->groupName(Device));
-                devitems.insert(r, url);
+                if (smbIp.isEmpty())
+                    devitems.insert(r, url);
             }
             //还原url
             if (m_currentUrl == fi->redirectedFileUrl())
                 setCurrentUrl(m_currentUrl, false);
         }
     });
-    connect(devicesWatcher, &DAbstractFileWatcher::fileDeleted, this, [this](const DUrl & url) {
+    connect(devicesWatcher, &DAbstractFileWatcher::fileDeleted, this, [=/*this*/](const DUrl & url) {
+        if(FileUtils::isSmbHostOnly(url)){//url like: smb://x.x.x.x
+            this->removeItem(url,"device");
+            return;
+        }
         bool curUrlCanAccess = true; // 初始化为true 避免影响原有逻辑
         auto fi = fileService->createFileInfo(nullptr, m_currentUrl);
         if (fi)
             curUrlCanAccess = fi->exists();
         int index = findItem(url, groupName(Device));
         int curIndex = m_sidebarView->currentIndex().row();
-        if ((curIndex == index && index != -1)
-                || (!curUrlCanAccess)) {
+        QString smbIp;
+        bool isSmbRelatedPath = FileUtils::isSmbRelatedUrl(url, smbIp);
+        bool switchToComputerItem = false;
+        int remainMountedCount = 0;
+        bool isBathUnmuntSmb = devicesWatcher->property("isBathUnmuntSmb").toBool();//批量卸载
+        bool lastOneShareFolderRemved = false;
+        if (isSmbRelatedPath){
+            remainMountedCount = devicesWatcher->property("remainUnmuntSmb").toInt();//每卸载一个，这里的值会递减1
+            if (remainMountedCount <=0 ){//SMB设备已经没有挂载着的共享目录了
+                //标识最后一个SMB挂载目录已被卸载，可以从侧边栏移除（具体是否可以移除，还要看配置GA_AlwaysShowOfflineRemoteConnections）
+                lastOneShareFolderRemved = true;
+                QString smbDeviceStr = QString("%1://%2").arg(SMB_SCHEME).arg(smbIp);
+                RemoteMountsStashManager::removeStashedSmbDevice(smbDeviceStr);//当smbip下，所有挂载项都被移除后，从配置中移除
 
+                DUrl smbDevice(smbDeviceStr);
+
+                if (!secretManager->userCheckedRememberPassword(smbDevice)){//如果挂载共享目录鉴权时，用户没有勾选记住密码
+                   secretManager->clearPassworkBySmbHost(smbDevice);//取消记住密码
+                   deviceListener->clearLoginData();//清除登录数据，以便下次重新弹出鉴权对话框
+                }
+            }
+
+            bool keepSmb = DFMApplication::genericAttribute(DFMApplication::GA_AlwaysShowOfflineRemoteConnections).toBool();
+            //如果最后一个SMB挂载已被移除 且 配置为 （无需常驻SMB挂载 或 是批量卸载），需要跳转到计算机界面和从侧边栏移除smb聚合项
+            if (lastOneShareFolderRemved && (!keepSmb || isBathUnmuntSmb)){
+                switchToComputerItem = true;
+                deviceListener->setBatchedRemovingSmbMount(false);
+                //The smb ip item data like: smb://xx.xx.xx.xx
+                emit rootFileManager->rootFileWather()->fileDeleted(DUrl(QString("%1://%2").arg(SMB_SCHEME).arg(smbIp)));
+            }
+        }
+        switchToComputerItem = switchToComputerItem && (!(isBathUnmuntSmb && remainMountedCount>0));
+         if ((curIndex == index && index != -1)
+                || (!curUrlCanAccess) || switchToComputerItem) {
             DUrl urlSkip;
             const QString &absFilePath = url.toAbsolutePathUrl().path();
             QString localFilePath = QUrl::fromPercentEncoding(url.path().toLocal8Bit());
             localFilePath = localFilePath.startsWith("//") ? localFilePath.mid(1) : localFilePath;
-
-            const auto &allDevice = deviceListener->getAllDeviceInfos();
             bool blockDevice = false;
+            const auto &allDevice = deviceListener->getAllDeviceInfos();
             for (const auto &dev : allDevice.keys()) {
                 if (dev.contains(absFilePath.left(absFilePath.indexOf(".localdisk")))) {
                     blockDevice = true;
@@ -818,31 +988,28 @@ void DFMSideBar::initDeviceConnection()
 
             // 判断删除的路径是否是外设路径，外设路径需要跳转到computer页面
             bool turnToComputer = false;
-            if (deviceListener->isInDeviceFolder(absFilePath)
+            if (switchToComputerItem || (deviceListener->isInDeviceFolder(absFilePath)
                     || localFilePath.startsWith("/run/user")
                     || localFilePath.startsWith("/media/")
                     || blockDevice // like u disk
-                    || FileUtils::isGvfsMountFile(localFilePath)
-                    ) {
+                    || FileUtils::isGvfsMountFile(localFilePath) ))
+                    {
                 urlSkip = DUrl(COMPUTER_ROOT);
                 turnToComputer = true;
             } else {
                 urlSkip = DUrl::fromLocalFile(QDir::homePath());
             }
+            DFileManagerWindow *window = qobject_cast<DFileManagerWindow *>(this->window());
 
-            index = findItem(urlSkip, groupName(turnToComputer ? Device : Common));
-            DFMSideBarItem *item = m_sidebarModel->itemFromIndex(index);
-            if (item) {
-                QString identifierStr = item->registeredHandler(SIDEBAR_ID_INTERNAL_FALLBACK);
-                QScopedPointer<DFMSideBarItemInterface> interface(DFMSideBarManager::instance()->createByIdentifier(identifierStr));
-                if (interface) {
-                    interface->cdAction(this, item);
-                }
-            }
+            //后面会根据switchToComputerItem为true去removeItem(), 因此此前不能改变switchToComputerItem的状态
+            if(switchToComputerItem && window && window->isActiveWindow())
+                this->jumpToItem(urlSkip);
         }
         //DFileService::instance()->changeRootFile(url,false); //性能优化，注释
-        this->removeItem(url, this->groupName(Device));
+        if ( !isSmbRelatedPath || switchToComputerItem)
+            this->removeItem(url, this->groupName(Device));
         devitems.removeAll(url);
+
     });
     connect(devicesWatcher, &DAbstractFileWatcher::fileAttributeChanged, this, [this](const DUrl & url) {
         int index = findItem(url, groupName(Device));
@@ -1004,7 +1171,7 @@ void DFMSideBar::addGroupItems(DFMSideBar::GroupName groupType)
         if (m_disableUrlSchemes.contains(BOOKMARK_SCHEME))  {
             break;
         }
-
+        bookmarkManager->initData();
         const DUrlList urlList = bookmarkManager->getBookmarkUrls();
         QList<DFMSideBarItem *> unsortedList;
         for (const DUrl &url : urlList) {
