@@ -81,7 +81,9 @@ public:
     static const int minimumWidth = 120;
     static const int maximumWidth = 200;
     void rootFileResult();
-
+    void jumpToItem(const DUrl& url, GroupName group = Device);
+private:
+    bool isSmbItemExisted(const DUrl &smbDevice);
 signals:
     void disableUrlSchemesChanged();
     // 侧边栏添加共享item信号，url为共享文件夹的路径
@@ -125,7 +127,6 @@ private:
     DFMSideBarItem *m_pLastToggleItem = nullptr;
     DUrl m_currentUrl;
     QMutex m_currentUrlMutex;
-
 #ifdef ENABLE_ASYNCINIT
     QPair<bool,QFuture<void>> m_initDevThread; //初始化initDeviceConnection线程，first为是否强制结束线程
 #endif
