@@ -47,6 +47,8 @@ private:
     void initializeConnect();
 
     void processTags();
+    void updateCrumbsColor(const QMap<QString, QColor> &tagsColor);
+    QMap<QString, QColor> tagsColor(const QStringList &tagList);
 
     void onPressESC() noexcept;
 
@@ -59,7 +61,6 @@ private:
 
     std::atomic<bool> m_flagForShown{ false };
 
-    bool m_isSettingDefault = false;
     QTimer m_waitForMoreCrumbChanged;   //用于等待短时间内的多次CrumbChanged
 };
 
