@@ -151,8 +151,8 @@ void PdfWidget::initUI()
 
     initEmptyPages();
 
-    loadThumbSync(0);
-    loadPageSync(0);
+    loadThumbAsync(0);
+    loadPageAsync(0);
 }
 
 void PdfWidget::initConnections()
@@ -327,7 +327,7 @@ void PdfWidget::startLoadCurrentPages()
     if(item)
     {
         int row = d->pageListWidget->row(item);
-        loadPageSync(row);
+        loadPageAsync(row);
     }
 }
 
@@ -343,7 +343,7 @@ void PdfWidget::startLoadCurrentThumbs()
     if(item)
     {
         int row = d->thumbListWidget->row(item);
-        loadThumbSync(row);
+        loadThumbAsync(row);
     }
 }
 
@@ -405,7 +405,7 @@ void PdfWidget::emptyBorder(QImage &img)
     painter.drawRect(0, 0, img.width() - 2, img.height() - 2);
 }
 
-void PdfWidget::loadPageSync(const int &index)
+void PdfWidget::loadPageAsync(const int &index)
 {
     Q_D(PdfWidget);
 
@@ -422,7 +422,7 @@ void PdfWidget::loadPageSync(const int &index)
                     });
 }
 
-void PdfWidget::loadThumbSync(const int &index)
+void PdfWidget::loadThumbAsync(const int &index)
 {
     Q_D(PdfWidget);
 
