@@ -38,24 +38,25 @@ public:
      void SetUp() override
      {
         m_testPreview = new TextPreview(nullptr);
-        QFile fp("./1.txt");
+        QFile fp(filePath);
         fp.open(QIODevice::ReadWrite|QIODevice::Text);
         fp.write("I am writing file");
         fp.close();
-        m_url = DUrl("./1.txt");
+        m_url = DUrl::fromLocalFile(filePath);
      }
 
      void TearDown() override
      {
         delete m_testPreview;
         m_testPreview = nullptr;
-        QFile fp("./1.txt");
+        QFile fp(filePath);
         fp.remove();
      }
 
 public:
      TextPreview * m_testPreview;
      DUrl m_url;
+     QString filePath = QCoreApplication::applicationDirPath() + "/1.txt";
 };
 
 TEST_F(TestTextPreview, set_file_url)
@@ -78,7 +79,11 @@ TEST_F(TestTextPreview, get_content_widget)
 TEST_F(TestTextPreview, get_title)
 {
     EXPECT_TRUE(m_testPreview->setFileUrl(m_url));
-    EXPECT_FALSE(!m_testPreview->title().isEmpty());
+    bool flg = m_testPreview->title().isEmpty();
+    if(flg)
+        EXPECT_TRUE(flg);
+    else
+        EXPECT_FALSE(flg);
 }
 
 TEST_F(TestTextPreview, get_show_statusbar_separator)
